@@ -702,13 +702,16 @@ class Connection:
         dataset_json = utils.parse_json_response(response)
         return Dataset(self, dataset_json)
 
-    def get_pipes(self, include_internal_pipes=False, **kwargs):
+    def get_pipes(self, include_internal_pipes=False, fields=None, **kwargs):
         pipes = []
 
         # TODO: wrap in a utility-method and add error-detection
         request_params = {}
         if include_internal_pipes:
             request_params["include-internal-pipes"] = "true"
+
+        if fields is not None:
+            request_params["fields"] = fields
         response = self.do_get_request(self.pipes_url,
                                        allowable_response_status_codes=[200],
                                        params=request_params, **kwargs
@@ -720,8 +723,13 @@ class Connection:
             pipes.append(Pipe(self, pipe_json))
         return pipes
 
-    def get_pipe(self, pipe_id, **kwargs):
+    def get_pipe(self, pipe_id, fields=None, **kwargs):
         # TODO: wrap in a utility-method and add error-detection
+
+        request_params = kwargs.pop("request_params", {})
+
+        if fields is not None:
+            request_params["fields"] = ",".join(fields)
         response = self.do_get_request(self.get_pipe_url(pipe_id), **kwargs)
         if response.status_code == 404:
             return None
